#!/usr/bin/perl

# Author : Damien KROTKINE (dams@gentoo.org)
#
# Contributors : 
#
# Copyright (C) 2002-2005 Damien KROTKINE (dams@gentoo.org)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

package Libconf::Glueconf::Networking::Hosts;
use strict;
use Libconf::Templates;
use Libconf::Glueconf::System::Passwd;
use Libconf::Templates::Generic::KeyValues;

our @ISA = qw(Libconf::Glueconf::System::Passwd);

sub new {
    my ($class, $args) = @_;
    my $libconf = new Libconf::Templates::Generic::KeyValues(init_args($args, {
                                                                               regexp => '^\s*(\S+)\s+(\S+)\s+(.*?)\s*$',
                                                                               keys_list => [qw(IP_address canonical_hostname aliases)],
                                                                               identifier_key => 'IP_address',
                                                                               output_function => sub { my $atom = shift; join("\t", map { $atom->{values}{$_} } @_ ) },
                                                                              }));
    $libconf->read_conf();
    tie my %wrapper, 'Libconf::Glueconf::System::Passwd::Wrapper', $libconf;
    bless \%wrapper, $class;

}

sub description { 'template for the hosts (/etc/hosts) configuration file' }

1;
